@@ -71,7 +71,6 @@ std::string GetDebugReportsLog(DebugActionFlags flags);
 #define kLayerSettingsExcludeDeviceExtensions "exclude_device_extensions"
 #define kLayerSettingsExcludeFormats "exclude_formats"
 #define kLayerSettingsDefaultFeatureValues "default_feature_values"
-#define kLayerSettingsForceDevice "force_device"
-#define kLayerSettingsForceDeviceUUID "force_device_uuid"
-#define kLayerSettingsForceDeviceName "force_device_name"
+#define kLayerSettingsUnknownFeatureValues "unknown_feature_values"
+
 
