@@ -170,18 +170,6 @@ void LogFlush(ProfileLayerSettings *layer_settings) {
     }
 }
 
-static ForceDevice GetForceDevice(const std::string &value) {
-    if (value == "FORCE_DEVICE_OFF") {
-        return FORCE_DEVICE_OFF;
-    } else if (value == "FORCE_DEVICE_WITH_UUID") {
-        return FORCE_DEVICE_WITH_UUID;
-    } else if (value == "FORCE_DEVICE_WITH_NAME") {
-        return FORCE_DEVICE_WITH_NAME;
-    }
-
-    return FORCE_DEVICE_OFF;
-}
-
 static std::vector<std::string> Split(const std::string &value, const std::string &delimiter) {
     std::vector<std::string> result;
 
@@ -245,13 +233,11 @@ void InitProfilesLayerSettings(const VkInstanceCreateInfo *pCreateInfo, const Vk
                                               kLayerSettingsExcludeDeviceExtensions,
                                               kLayerSettingsExcludeFormats,
                                               kLayerSettingsDefaultFeatureValues,
-                                              kLayerSettingsForceDevice,
-                                              kLayerSettingsForceDeviceUUID,
-                                              kLayerSettingsForceDeviceName};
+                                              kLayerSettingsUnknownFeatureValues};
         uint32_t setting_name_count = static_cast<uint32_t>(std::size(setting_names));
 
         std::vector<const char *> unknown_settings;
-        vkuGetUnknownSettings(create_info, setting_name_count, setting_names, unknown_settings);
+        vkuGetUnknownSettings(layerSettingSet, setting_name_count, setting_names, create_info, unknown_settings);
 
         for (std::size_t i = 0, n = unknown_settings.size(); i < n; ++i) {
             LogMessage(layer_settings, DEBUG_REPORT_WARNING_BIT,
@@ -307,6 +293,12 @@ void InitProfilesLayerSettings(const VkInstanceCreateInfo *pCreateInfo, const Vk
         }
     }
 
+    if (vkuHasLayerSetting(layerSettingSet, kLayerSettingsUnknownFeatureValues)) {
+        std::string value;
+        vkuGetLayerSettingValue(layerSettingSet, kLayerSettingsUnknownFeatureValues, value);
+        layer_settings->simulate.unknown_feature_values = GetUnknownFeatureValues(ToUpper(value));
+    }
+
     if (vkuHasLayerSetting(layerSettingSet, kLayerSettingsExcludeDeviceExtensions)) {
         vkuGetLayerSettingValues(layerSettingSet, kLayerSettingsExcludeDeviceExtensions,
                                  layer_settings->simulate.exclude_device_extensions);
@@ -397,20 +389,6 @@ void InitProfilesLayerSettings(const VkInstanceCreateInfo *pCreateInfo, const Vk
         }
     }
 
-    if (vkuHasLayerSetting(layerSettingSet, kLayerSettingsForceDevice)) {
-        std::string value;
-        vkuGetLayerSettingValue(layerSettingSet, kLayerSettingsForceDevice, value);
-        layer_settings->device.force_device = GetForceDevice(ToUpper(value));
-
-        if (vkuHasLayerSetting(layerSettingSet, kLayerSettingsForceDeviceUUID)) {
-            vkuGetLayerSettingValue(layerSettingSet, kLayerSettingsForceDeviceUUID, layer_settings->device.force_device_uuid);
-        }
-
-        if (vkuHasLayerSetting(layerSettingSet, kLayerSettingsForceDeviceName)) {
-            vkuGetLayerSettingValue(layerSettingSet, kLayerSettingsForceDeviceName, layer_settings->device.force_device_name);
-        }
-    }
-
     if (vkuHasLayerSetting(layerSettingSet, kLayerSettingsDebugFailOnError)) {
         vkuGetLayerSettingValue(layerSettingSet, kLayerSettingsDebugFailOnError, layer_settings->log.debug_fail_on_error);
     }
@@ -461,6 +439,7 @@ void InitProfilesLayerSettings(const VkInstanceCreateInfo *pCreateInfo, const Vk
     const std::string profile_dirs = GetString(layer_settings->simulate.profile_dirs);
     const std::string simulation_capabilities_log = GetSimulateCapabilitiesLog(layer_settings->simulate.capabilities);
     const std::string default_feature_values = GetDefaultFeatureValuesString(layer_settings->simulate.default_feature_values);
+    const std::string unknown_feature_values = GetUnknownFeatureValuesString(layer_settings->simulate.unknown_feature_values);
     const std::string debug_actions_log = GetDebugActionsLog(layer_settings->log.debug_actions);
     const std::string debug_reports_log = GetDebugReportsLog(layer_settings->log.debug_reports);
 
@@ -473,6 +452,7 @@ void InitProfilesLayerSettings(const VkInstanceCreateInfo *pCreateInfo, const Vk
         format("\t%s: %s\n", kLayerSettingsProfileValidation, layer_settings->simulate.profile_validation ? "true" : "false");
     settings_log += format("\t%s: %s\n", kLayerSettingsSimulateCapabilities, simulation_capabilities_log.c_str());
     settings_log += format("\t%s: %s\n", kLayerSettingsDefaultFeatureValues, default_feature_values.c_str());
+    settings_log += format("\t%s: %s\n", kLayerSettingsUnknownFeatureValues, unknown_feature_values.c_str());
 
     settings_log +=
         format("\t%s: %s\n", kLayerSettingsEmulatePortability, layer_settings->simulate.emulate_portability ? "true" : "false");
