@@ -1,6 +1,7 @@
 /*
- * Copyright (C) 2021-2024 Valve Corporation
- * Copyright (C) 2021-2024 LunarG, Inc.
+ * Copyright (C) 2021-2025 Valve Corporation
+ * Copyright (C) 2021-2025 LunarG, Inc.
+ * Copyright (c) 2024 RasterGrid Kft.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -40,7 +41,8 @@ class TestsIntersection : public VkTestFramework {
         const char* profile_name_data = "VP_LUNARG_test_combine_intersect"; 
         VkBool32 emulate_portability_data = VK_TRUE;
         const std::vector<const char*> simulate_capabilities = {
-            "SIMULATE_API_VERSION_BIT", "SIMULATE_FEATURES_BIT", "SIMULATE_PROPERTIES_BIT", "SIMULATE_EXTENSIONS_BIT", "SIMULATE_FORMATS_BIT", "SIMULATE_QUEUE_FAMILY_PROPERTIES_BIT"};
+            "SIMULATE_API_VERSION_BIT", "SIMULATE_FEATURES_BIT", "SIMULATE_PROPERTIES_BIT", "SIMULATE_EXTENSIONS_BIT", "SIMULATE_FORMATS_BIT",
+            "SIMULATE_QUEUE_FAMILY_PROPERTIES_BIT", "SIMULATE_VIDEO_CAPABILITIES_BIT", "SIMULATE_VIDEO_FORMATS_BIT"};
         const std::vector<const char*> debug_reports = {
             "DEBUG_REPORT_ERROR_BIT", "DEBUG_REPORT_WARNING_BIT", "DEBUG_REPORT_NOTIFICATION_BIT", "DEBUG_REPORT_DEBUG_BIT"};
 
@@ -96,7 +98,7 @@ TEST_F(TestsIntersection, Properties) {
     EXPECT_TRUE(std::abs(gpu_props.limits.maxSamplerAnisotropy - 1.0) < 0.0001);
     EXPECT_EQ(gpu_props.limits.viewportBoundsRange[0], -16384);
     EXPECT_EQ(gpu_props.limits.viewportBoundsRange[1], 16384);
-    EXPECT_EQ(gpu_props.limits.minMemoryMapAlignment, 4096);
+    EXPECT_EQ(gpu_props.limits.minMemoryMapAlignment, 64);
     EXPECT_EQ(gpu_props.limits.minTexelOffset, -4);
     EXPECT_EQ(gpu_props.limits.maxTexelOffset, 3);
     EXPECT_EQ(gpu_props.limits.framebufferColorSampleCounts, VK_SAMPLE_COUNT_4_BIT);
